django_dicom.serializers package — django_dicom 0.1.0 documentation

# django_dicom.serializers package

## Module contents

Provides serializers for the REST API.

## Submodules

## django_dicom.serializers.image_serializer module

class `django_dicom.serializers.image_serializer.` `ImageSerializer`(instance=None, data=<class 'rest_framework.fields.empty'>, **kwargs)

  Bases: `rest_framework.serializers.HyperlinkedModelSerializer`

  A serializer class for the `Image` model.

  class `Meta`

    Bases: `object`

    `fields` = ('id', 'series', 'number', 'date', 'time', 'uid')
    `model`

      alias of `django_dicom.models.image.Image`

## django_dicom.serializers.patient_serializer module

class `django_dicom.serializers.patient_serializer.` `PatientSerializer`(instance=None, data=<class 'rest_framework.fields.empty'>, **kwargs)

  Bases: `rest_framework.serializers.HyperlinkedModelSerializer`

  A serializer class for the `Patient` model.

  class `Meta`

    Bases: `object`

    `fields` = ('id', 'uid', 'name_prefix', 'given_name', 'middle_name', 'family_name', 'name_suffix', 'sex', 'date_of_birth', 'subject')
    `model`

      alias of `django_dicom.models.patient.Patient`

## django_dicom.serializers.series_serializer module

class `django_dicom.serializers.series_serializer.` `SeriesSerializer`(instance=None, data=<class 'rest_framework.fields.empty'>, **kwargs)

  Bases: `rest_framework.serializers.HyperlinkedModelSerializer`

  A serializer class for the `Series` model.

  class `Meta`

    Bases: `object`

    `fields` = ('id', 'url', 'study', 'patient', 'body_part_examined', 'patient_position', 'number', 'description', 'date', 'time', 'modality', 'protocol_name', 'scanning_sequence', 'sequence_variant', 'pixel_spacing', 'slice_thickness', 'echo_time', 'inversion_time', 'repetition_time', 'flip_angle', 'manufacturer', 'manufacturer_model_name', 'magnetic_field_strength', 'device_serial_number', 'institution_name', 'uid')
    `model`

      alias of `django_dicom.models.series.Series`

## django_dicom.serializers.study_serializer module

class `django_dicom.serializers.study_serializer.` `StudySerializer`(instance=None, data=<class 'rest_framework.fields.empty'>, **kwargs)

  Bases: `rest_framework.serializers.HyperlinkedModelSerializer`

  A serializer class for the `Study` model.

  class `Meta`

    Bases: `object`

    `fields` = ('id', 'description', 'date', 'time', 'uid')
    `model`

      alias of `django_dicom.models.study.Study`